==> nextcloud-27.1.7p0.tgz: nextcloud/apps/privacy/l10n/ko.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "개인 정보 취급 방침",
    "-" : "-",
    "Administrators" : "관리자",
    "Add external admin" : "외부 관리자 추가",
    "Cancel" : "취소",
    "Add" : "추가",
    "Name of external admin" : "외부 관리자 이름",
    "Encryption" : "암호화",
    "Edit" : "편집",
    "This server is using full-disk-encryption." : "이 서버에서 전체 디스크 암호화를 사용하고 있습니다.",
    "Additionally, this server is protected with full-disk-encryption." : "추가적으로, 이 서버는 전체 디스크 암호화로 보호됩니다.",
    "This server is protected with full-disk-encryption." : "이 서버는 전체 디스크 암호화로 보호됩니다.",
    "Your files are not protected by encryption." : "파일이 더 이상 암호화로 보호되지 않습니다.",
    "Privacy policy" : "개인 정보 취급 방침",
    "Who has access to your data?" : "누가 내 데이터에 접근할 수 있나요?",
    "Where is your data?" : "내 데이터는 어디에 있나요?",
    "Your data is located in:" : "귀하의 데이터는 여기에 있습니다:",
    "Change data location" : "데이터 위치 변경",
    "Region" : "지역",
    "Please select a region" : "지역을 선택하세요.",
    "User Data Manifesto 2.0" : "User Data Manifesto 2.0",
    "Control" : "제어:",
    "over user data access" : "사용자 데이터 접근",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "사용자가 직접 명시적으로 업로드한 데이터는 사용자의 제어 하에 있어야 합니다. 사용자는 누가 데이터에 직접 접근하고, 어떤 권한과 라이선스로 접근을 허가할지 결정할 수 있습니다.",
    "Knowledge" : "지식:",
    "of how the data is stored" : "데이터 저장 방법",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "데이터를 서비스 공급자에 업로드했을 때 사용자는 서비스 공급자가 어디에 데이터를 저장하고, 얼마 동안 데이터를 저장하고, 어느 지역에서 영업하며, 어떤 법률이 적용되는지 알아야 합니다.",
    "Freedom" : "자유:",
    "to choose a platform" : "플랫폼 선택",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "사용자는 언제든지 서비스 제공자로부터 제한 없이 데이터를 추출할 수 있어야 합니다. 이를 보장하려면 공개된 데이터 형식과 프로토콜이 필수적입니다.",
    "Learn more ↗" : "더 알아보기 ↗",
    "Your {serverName} account" : "내 {serverName} 계정",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "사용자의 데이터를 통해 해당 사용자가 어떤 사람인지 알 수 있으며, 이는 쉽게 오남용될 수 있습니다. 저희 Nextcloud는 모든 사람이 자신의 데이터 활용을 스스로 결정할 수 있는 권리가 있다고 믿습니다. Nextcloud는 사용자 데이터 선언(User Data Manifesto)에서 정의한 대로 사용자의 권리를 보호합니다!",
    "Somaliland" : "소말릴란드",
    "Andorra" : "안도라",
    "United Arab Emirates" : "아랍에미리트",
    "Afghanistan" : "아프가니스탄",
    "Antigua and Barbuda" : "앤티가바부다",
    "Anguilla" : "앵귈라",
    "Albania" : "알바니아",
    "Armenia" : "아르메니아",
    "Angola" : "앙골라",
    "Antarctica" : "남극",
    "Argentina" : "아르헨티나",
    "American Samoa" : "미국령 사모아",
    "Austria" : "오스트리아",
    "Australia" : "오스트레일리아",
    "Aruba" : "아루바",
    "Åland Islands" : "올란드 제도",
    "Azerbaijan" : "아제르바이잔",
    "Bosnia and Herzegovina" : "보스니아 헤르체고비나",
    "Barbados" : "바베이도스",
    "Bangladesh" : "방글라데시",
    "Belgium" : "벨기에",
    "Burkina Faso" : "부르키나 파소",
    "Bulgaria" : "불가리아",
    "Bahrain" : "바레인",
    "Burundi" : "부룬디",
    "Benin" : "베냉",
    "Saint Barthélemy" : "성 바르텔레미",
    "Bermuda" : "버뮤다",
    "Brunei" : "브루나이",
    "Bolivia" : "볼리비아",
    "Bonaire, Sint Eustatius and Saba" : "보나이러",
    "Brazil" : "브라질",
    "Bahamas" : "바하마",
    "Bhutan" : "부탄",
    "Bouvet Island" : "부베 섬",
    "Botswana" : "보츠와나",
    "Belarus" : "벨라루스",
    "Belize" : "벨리즈",
    "Canada" : "캐나다",
    "Cocos (Keeling) Islands" : "코코스 킬링 제도",
    "Democratic Republic of the Congo" : "콩고민주공화국",
    "Central African Republic" : "중앙아프리카공화국",
    "Congo" : "콩고",
    "Switzerland" : "스위스",
    "Cote d'Ivoire" : "코트디부아르",
    "Cook Islands" : "쿡 제도",
    "Chile" : "칠레",
    "Cameroon" : "카메룬",
    "China" : "중국",
    "Colombia" : "콜롬비아",
    "Costa Rica" : "코스타리카",
    "Cuba" : "쿠바",
    "Cabo Verde" : "카보베르데",
    "Curaçao" : "퀴라소",
    "Christmas Island" : "크리스마스 섬",
    "Cyprus" : "사이프러스",
    "Czech" : "체코어",
    "Germany" : "독일",
    "Djibouti" : "지부티",
    "Denmark" : "덴마크",
    "Dominican Republic" : "도미니카공화국",
    "Algeria" : "알제리",
    "Ecuador" : "에콰도르",
    "Estonia" : "에스토니아",
    "Egypt" : "이집트",
    "West Sahara" : "서사하라",
    "Eritrea" : "에리트레아",
    "Spain" : "스페인",
    "Ethiopia" : "에티오피아",
    "Finland" : "핀란드",
    "Fiji" : "피지",
    "Falkland Islands" : "포글랜드 제도",
    "Micronesia" : "미크로네시아",
    "Faroe Islands" : "패로제도",
    "France" : "프랑스",
    "Gabon" : "가봉",
    "United Kingdom" : "영국",
    "Grenada" : "그레나다",
    "Georgia" : "조지아",
    "French Guiana" : "프랑스령 기아나",
    "Guernsey" : "건지",
    "Ghana" : "가나",
    "Gibraltar" : "지브롤터",
    "Greenland" : "그린랜드",
    "Gambia" : "잠비아",
    "Guinea" : "기니",
    "Guadeloupe" : "과들루프",
    "Equatorial Guinea" : "적도 기니",
    "Greece" : "그리스",
    "South Georgia and the South Sandwich Islands" : "사우스조지아 사우스샌드위치 제도",
    "Guatemala" : "과테말라",
    "Guam" : "괌",
    "Guinea-Bissau" : "기니비사우",
    "Guyana" : "가이아나",
    "Hong Kong" : "홍콩",
    "Heard Island and McDonald Islands" : "허드 맥도널드 제도",
    "Honduras" : "온두라스",
    "Croatia" : "크로아티아",
    "Haiti" : "아이티",
    "Hungary" : "헝가리",
    "Indonesia" : "인도네시아",
    "Ireland" : "아일랜드",
    "Israel" : "이스라엘",
    "Isle of Man" : "맨섬",
    "India" : "인도",
    "British Indian Ocean Territory" : "영국령인도양식민지",
    "Iraq" : "이라크",
    "Iran" : "이란",
    "Iceland" : "아이슬란드",
    "Italy" : "이탈리아",
    "Jamaica" : "자메이카",
    "Jordan" : "요르단",
    "Japan" : "일본",
    "Kenya" : "케냐",
    "Kyrgyzstan" : "키르기스스탄",
    "Cambodia" : "캄보디아",
    "Kiribati" : "키리바시",
    "Saint Kitts and Nevis" : "세인트키츠 네비스",
    "North Korea" : "북한",
    "South Korea" : "대한민국",
    "Kuwait" : "쿠웨이트",
    "Cayman Islands" : "케이맨 제도",
    "Kazakhstan" : "카자흐스탄",
    "Laos" : "라오스",
    "Lebanon" : "레바논",
    "Saint Lucia" : "세인트루시아",
    "Liechtenstein" : "리히텐슈타인",
    "Sri Lanka" : "스리랑카",
    "Liberia" : "라이베리아",
    "Lesotho" : "레소토",
    "Lithuania" : "리투아니아",
    "Luxembourg" : "룩셈부르크",
    "Latvia" : "라트비아",
    "Libya" : "리비아",
    "Morocco" : "모로코",
    "Monaco" : "모나코",
    "Moldova" : "몰도바",
    "Montenegro" : "몬테네그로",
    "Madagascar" : "마다가스카르",
    "Marshall Islands" : "마셜제도",
    "Macedonia" : "마케도니아",
    "Mali" : "말리",
    "Myanmar" : "미얀마",
    "Mongolia" : "몽골",
    "Macao" : "마카오",
    "Northern Mariana Islands" : "북마리아나제도",
    "Mauritania" : "모리타니",
    "Montserrat" : "몬세라트",
    "Malta" : "몰타",
    "Mauritius" : "모리셔스",
    "Maldives" : "몰디브",
    "Malawi" : "말라위",
    "Mexico" : "멕시코",
    "Malaysia" : "말레이시아",
    "Mozambique" : "모잠비크",
    "Namibia" : "나미비아",
    "New Caledonia" : "뉴칼레도니아",
    "Niger" : "니제르",
    "Norfolk Island" : "노퍽 섬",
    "Nigeria" : "나이지리아",
    "Nicaragua" : "니카라과",
    "Netherlands" : "네덜란드",
    "Norway" : "노르웨이",
    "Nepal" : "네팔",
    "Nauru" : "나우루",
    "Niue" : "니우에 섬",
    "New Zealand" : "뉴질랜드",
    "Oman" : "오만",
    "Panama" : "파나마",
    "Peru" : "페루",
    "French Polynesia" : "프랑스령폴리네시아",
    "Papua New Guinea" : "파푸아뉴기니",
    "Philippines" : "필리핀",
    "Pakistan" : "파키스탄",
    "Poland" : "폴란드",
    "Saint Pierre and Miquelon" : "생피에르 미클롱",
    "Pitcairn" : "핏케언 제도",
    "Puerto Rico" : "푸에르토리코",
    "Palestine" : "팔레스타인",
    "Portugal" : "포르투갈",
    "Palau" : "팔라우",
    "Paraguay" : "파라과이",
    "Qatar" : "카타르",
    "Réunion" : "레위니옹",
    "Romania" : "루마니아",
    "Serbia" : "세르비아",
    "Russia" : "러시아",
    "Rwanda" : "르완다",
    "Saudi Arabia" : "사우디아라비아",
    "Solomon Islands" : "솔로몬제도",
    "Seychelles" : "세이셸",
    "Sudan" : "수단",
    "Sweden" : "스웨덴",
    "Singapore" : "싱가포르",
    "Saint Helena, Ascension and Tristan da Cunha" : "세인트헬레나 어센션 트리스탄다쿠냐",
    "Slovenia" : "슬로베니아",
    "Svalbard and Jan Mayen" : "스발바르 얀마옌 제도",
    "Slovakia" : "슬로바키아",
    "Sierra Leone" : "시에라리온",
    "San Marino" : "산마리노",
    "Senegal" : "세네갈",
    "Somalia" : "소말리아",
    "Suriname" : "수리남",
    "South Sudan" : "남수단",
    "Sao Tome and Principe" : "상투메 프린시페 민주 공화국",
    "El Salvador" : "엘살바도르",
    "Syria" : "시리아",
    "Swaziland" : "에스와티니",
    "Turks and Caicos Islands" : "터크스카이코스 제도",
    "Chad" : "차드",
    "Togo" : "토고",
    "Thailand" : "타이",
    "Tajikistan" : "타지키스탄",
    "Tokelau" : "토켈라우",
    "Timor-Leste" : "동티모르",
    "Turkmenistan" : "투르크메니스탄",
    "Tunisia" : "튀니지",
    "Tonga" : "통가",
    "Turkey" : "터키",
    "Trinidad and Tobago" : "트리니다드토바고",
    "Tuvalu" : "투발루",
    "Taiwan" : "대만",
    "Tanzania" : "탄자니아",
    "Ukraine" : "우크라이나",
    "Uganda" : "우간다",
    "United States Minor Outlying Islands" : "미국령 군소 제도",
    "United States" : "미국",
    "Uruguay" : "우루과이",
    "Uzbekistan" : "우즈베키스탄",
    "Holy See" : "바티칸시국",
    "Saint Vincent and the Grenadines" : "세인트빈센트 그레나딘",
    "Venezuela" : "베네수엘라",
    "Virgin Islands (British)" : "영국령 버진 아일랜드",
    "Virgin Islands (U.S.)" : "미국령 버진 아일랜드",
    "Vietnam" : "베트남",
    "Vanuatu" : "바누아투",
    "Wallis and Futuna" : "왈리스에푸투나",
    "Samoa" : "사모아",
    "Yemen" : "예멘",
    "Mayotte" : "마요트섬",
    "South Africa" : "남아프리카공화국",
    "Zambia" : "잠비아",
    "Zimbabwe" : "짐바브웨",
    "The admin has not selected the location of the server yet." : "관리자가 서버 위치를 지정하지 않았습니다.",
    "You don't have any shares with individual users." : "개인 사용자와 공유한 항목이 없습니다.",
    "Your %s account" : "내 %s 계정",
    "Defining basic rights for people to control their own data in the internet age" : "인터넷에서 사람들의 데이터를 제어하는 기본 권리 선언",
    "People you shared with" : "공유한 다른 사람",
    "Read the privacy policy." : "개인 정보 취급 방침을 읽습니다."
},
"nplurals=1; plural=0;");

==> nextcloud-28.0.7.tgz: nextcloud/apps/privacy/l10n/ko.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "개인 정보 취급 방침",
    "-" : "-",
    "Administrators" : "관리자",
    "Add external admin" : "외부 관리자 추가",
    "Cancel" : "취소",
    "Add" : "추가",
    "Name of external admin" : "외부 관리자 이름",
    "Encryption" : "암호화",
    "Edit" : "편집",
    "This server is using full-disk-encryption." : "이 서버에서 전체 디스크 암호화를 사용하고 있습니다.",
    "Additionally, this server is protected with full-disk-encryption." : "추가적으로, 이 서버는 전체 디스크 암호화로 보호됩니다.",
    "This server is protected with full-disk-encryption." : "이 서버는 전체 디스크 암호화로 보호됩니다.",
    "Your files are not protected by encryption." : "파일이 더 이상 암호화로 보호되지 않습니다.",
    "Privacy policy" : "개인 정보 취급 방침",
    "People you've shared with" : "내가 데이터를 공유한 사람",
    "Loading people you've shared with …" : "내가 데이터를 공유한 사람을 불러오는 중",
    "You do not have any shares with individual users." : "다른 사용자에게 내 데이터를 공유하지 않았습니다",
    "Who has access to your data?" : "누가 내 데이터에 접근할 수 있나요?",
    "Where is your data?" : "내 데이터는 어디에 있나요?",
    "Your data is located in:" : "귀하의 데이터는 여기에 있습니다:",
    "An admin has not selected the location of the server yet." : "관리자가 서버 위치를 지정하지 않았습니다.",
    "Change data location" : "데이터 위치 변경",
    "Region" : "지역",
    "Please select a region" : "지역을 선택하세요.",
    "User Data Manifesto 2.0" : "User Data Manifesto 2.0",
    "Defining basic rights for people to control their own data in the internet age." : "인터넷 시대의 자기정보통제권에 대한 기본 권리 선언",
    "Control" : "제어:",
    "over user data access" : "사용자 데이터 접근",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "사용자가 직접 명시적으로 업로드한 데이터는 사용자의 제어 하에 있어야 합니다. 사용자는 누가 데이터에 직접 접근하고, 어떤 권한과 라이선스로 접근을 허가할지 결정할 수 있습니다.",
    "Knowledge" : "지식:",
    "of how the data is stored" : "데이터 저장 방법",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "데이터를 서비스 공급자에 업로드했을 때 사용자는 서비스 공급자가 어디에 데이터를 저장하고, 얼마 동안 데이터를 저장하고, 어느 지역에서 영업하며, 어떤 법률이 적용되는지 알아야 합니다.",
    "Freedom" : "자유:",
    "to choose a platform" : "플랫폼 선택",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "사용자는 언제든지 서비스 제공자로부터 제한 없이 데이터를 추출할 수 있어야 합니다. 이를 보장하려면 공개된 데이터 형식과 프로토콜이 필수적입니다.",
    "Learn more ↗" : "더 알아보기 ↗",
    "Your {serverName} account" : "내 {serverName} 계정",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "사용자의 데이터를 통해 해당 사용자가 어떤 사람인지 알 수 있으며, 이는 쉽게 오남용될 수 있습니다. 저희 Nextcloud는 모든 사람이 자신의 데이터 활용을 스스로 결정할 수 있는 권리가 있다고 믿습니다. Nextcloud는 사용자 데이터 선언(User Data Manifesto)에서 정의한 대로 사용자의 권리를 보호합니다!",
    "Somaliland" : "소말릴란드",
    "Andorra" : "안도라",
    "United Arab Emirates" : "아랍에미리트",
    "Afghanistan" : "아프가니스탄",
    "Antigua and Barbuda" : "앤티가바부다",
    "Anguilla" : "앵귈라",
    "Albania" : "알바니아",
    "Armenia" : "아르메니아",
    "Angola" : "앙골라",
    "Antarctica" : "남극",
    "Argentina" : "아르헨티나",
    "American Samoa" : "미국령 사모아",
    "Austria" : "오스트리아",
    "Australia" : "오스트레일리아",
    "Aruba" : "아루바",
    "Åland Islands" : "올란드 제도",
    "Azerbaijan" : "아제르바이잔",
    "Bosnia and Herzegovina" : "보스니아 헤르체고비나",
    "Barbados" : "바베이도스",
    "Bangladesh" : "방글라데시",
    "Belgium" : "벨기에",
    "Burkina Faso" : "부르키나 파소",
    "Bulgaria" : "불가리아",
    "Bahrain" : "바레인",
    "Burundi" : "부룬디",
    "Benin" : "베냉",
    "Saint Barthélemy" : "성 바르텔레미",
    "Bermuda" : "버뮤다",
    "Brunei" : "브루나이",
    "Bolivia" : "볼리비아",
    "Bonaire, Sint Eustatius and Saba" : "보나이러",
    "Brazil" : "브라질",
    "Bahamas" : "바하마",
    "Bhutan" : "부탄",
    "Bouvet Island" : "부베 섬",
    "Botswana" : "보츠와나",
    "Belarus" : "벨라루스",
    "Belize" : "벨리즈",
    "Canada" : "캐나다",
    "Cocos (Keeling) Islands" : "코코스 킬링 제도",
    "Democratic Republic of the Congo" : "콩고민주공화국",
    "Central African Republic" : "중앙아프리카공화국",
    "Congo" : "콩고",
    "Switzerland" : "스위스",
    "Cote d'Ivoire" : "코트디부아르",
    "Cook Islands" : "쿡 제도",
    "Chile" : "칠레",
    "Cameroon" : "카메룬",
    "China" : "중국",
    "Colombia" : "콜롬비아",
    "Costa Rica" : "코스타리카",
    "Cuba" : "쿠바",
    "Cabo Verde" : "카보베르데",
    "Curaçao" : "퀴라소",
    "Christmas Island" : "크리스마스 섬",
    "Cyprus" : "사이프러스",
    "Czech" : "체코어",
    "Germany" : "독일",
    "Djibouti" : "지부티",
    "Denmark" : "덴마크",
    "Dominican Republic" : "도미니카공화국",
    "Algeria" : "알제리",
    "Ecuador" : "에콰도르",
    "Estonia" : "에스토니아",
    "Egypt" : "이집트",
    "West Sahara" : "서사하라",
    "Eritrea" : "에리트레아",
    "Spain" : "스페인",
    "Ethiopia" : "에티오피아",
    "Finland" : "핀란드",
    "Fiji" : "피지",
    "Falkland Islands" : "포글랜드 제도",
    "Micronesia" : "미크로네시아",
    "Faroe Islands" : "패로제도",
    "France" : "프랑스",
    "Gabon" : "가봉",
    "United Kingdom" : "영국",
    "Grenada" : "그레나다",
    "Georgia" : "조지아",
    "French Guiana" : "프랑스령 기아나",
    "Guernsey" : "건지",
    "Ghana" : "가나",
    "Gibraltar" : "지브롤터",
    "Greenland" : "그린랜드",
    "Gambia" : "잠비아",
    "Guinea" : "기니",
    "Guadeloupe" : "과들루프",
    "Equatorial Guinea" : "적도 기니",
    "Greece" : "그리스",
    "South Georgia and the South Sandwich Islands" : "사우스조지아 사우스샌드위치 제도",
    "Guatemala" : "과테말라",
    "Guam" : "괌",
    "Guinea-Bissau" : "기니비사우",
    "Guyana" : "가이아나",
    "Hong Kong" : "홍콩",
    "Heard Island and McDonald Islands" : "허드 맥도널드 제도",
    "Honduras" : "온두라스",
    "Croatia" : "크로아티아",
    "Haiti" : "아이티",
    "Hungary" : "헝가리",
    "Indonesia" : "인도네시아",
    "Ireland" : "아일랜드",
    "Israel" : "이스라엘",
    "Isle of Man" : "맨섬",
    "India" : "인도",
    "British Indian Ocean Territory" : "영국령인도양식민지",
    "Iraq" : "이라크",
    "Iran" : "이란",
    "Iceland" : "아이슬란드",
    "Italy" : "이탈리아",
    "Jamaica" : "자메이카",
    "Jordan" : "요르단",
    "Japan" : "일본",
    "Kenya" : "케냐",
    "Kyrgyzstan" : "키르기스스탄",
    "Cambodia" : "캄보디아",
    "Kiribati" : "키리바시",
    "Saint Kitts and Nevis" : "세인트키츠 네비스",
    "North Korea" : "북한",
    "South Korea" : "대한민국",
    "Kuwait" : "쿠웨이트",
    "Cayman Islands" : "케이맨 제도",
    "Kazakhstan" : "카자흐스탄",
    "Laos" : "라오스",
    "Lebanon" : "레바논",
    "Saint Lucia" : "세인트루시아",
    "Liechtenstein" : "리히텐슈타인",
    "Sri Lanka" : "스리랑카",
    "Liberia" : "라이베리아",
    "Lesotho" : "레소토",
    "Lithuania" : "리투아니아",
    "Luxembourg" : "룩셈부르크",
    "Latvia" : "라트비아",
    "Libya" : "리비아",
    "Morocco" : "모로코",
    "Monaco" : "모나코",
    "Moldova" : "몰도바",
    "Montenegro" : "몬테네그로",
    "Madagascar" : "마다가스카르",
    "Marshall Islands" : "마셜제도",
    "Macedonia" : "마케도니아",
    "Mali" : "말리",
    "Myanmar" : "미얀마",
    "Mongolia" : "몽골",
    "Macao" : "마카오",
    "Northern Mariana Islands" : "북마리아나제도",
    "Mauritania" : "모리타니",
    "Montserrat" : "몬세라트",
    "Malta" : "몰타",
    "Mauritius" : "모리셔스",
    "Maldives" : "몰디브",
    "Malawi" : "말라위",
    "Mexico" : "멕시코",
    "Malaysia" : "말레이시아",
    "Mozambique" : "모잠비크",
    "Namibia" : "나미비아",
    "New Caledonia" : "뉴칼레도니아",
    "Niger" : "니제르",
    "Norfolk Island" : "노퍽 섬",
    "Nigeria" : "나이지리아",
    "Nicaragua" : "니카라과",
    "Netherlands" : "네덜란드",
    "Norway" : "노르웨이",
    "Nepal" : "네팔",
    "Nauru" : "나우루",
    "Niue" : "니우에 섬",
    "New Zealand" : "뉴질랜드",
    "Oman" : "오만",
    "Panama" : "파나마",
    "Peru" : "페루",
    "French Polynesia" : "프랑스령폴리네시아",
    "Papua New Guinea" : "파푸아뉴기니",
    "Philippines" : "필리핀",
    "Pakistan" : "파키스탄",
    "Poland" : "폴란드",
    "Saint Pierre and Miquelon" : "생피에르 미클롱",
    "Pitcairn" : "핏케언 제도",
    "Puerto Rico" : "푸에르토리코",
    "Palestine" : "팔레스타인",
    "Portugal" : "포르투갈",
    "Palau" : "팔라우",
    "Paraguay" : "파라과이",
    "Qatar" : "카타르",
    "Réunion" : "레위니옹",
    "Romania" : "루마니아",
    "Serbia" : "세르비아",
    "Russia" : "러시아",
    "Rwanda" : "르완다",
    "Saudi Arabia" : "사우디아라비아",
    "Solomon Islands" : "솔로몬제도",
    "Seychelles" : "세이셸",
    "Sudan" : "수단",
    "Sweden" : "스웨덴",
    "Singapore" : "싱가포르",
    "Saint Helena, Ascension and Tristan da Cunha" : "세인트헬레나 어센션 트리스탄다쿠냐",
    "Slovenia" : "슬로베니아",
    "Svalbard and Jan Mayen" : "스발바르 얀마옌 제도",
    "Slovakia" : "슬로바키아",
    "Sierra Leone" : "시에라리온",
    "San Marino" : "산마리노",
    "Senegal" : "세네갈",
    "Somalia" : "소말리아",
    "Suriname" : "수리남",
    "South Sudan" : "남수단",
    "Sao Tome and Principe" : "상투메 프린시페 민주 공화국",
    "El Salvador" : "엘살바도르",
    "Syria" : "시리아",
    "Swaziland" : "에스와티니",
    "Turks and Caicos Islands" : "터크스카이코스 제도",
    "Chad" : "차드",
    "Togo" : "토고",
    "Thailand" : "타이",
    "Tajikistan" : "타지키스탄",
    "Tokelau" : "토켈라우",
    "Timor-Leste" : "동티모르",
    "Turkmenistan" : "투르크메니스탄",
    "Tunisia" : "튀니지",
    "Tonga" : "통가",
    "Turkey" : "터키",
    "Trinidad and Tobago" : "트리니다드토바고",
    "Tuvalu" : "투발루",
    "Taiwan" : "대만",
    "Tanzania" : "탄자니아",
    "Ukraine" : "우크라이나",
    "Uganda" : "우간다",
    "United States Minor Outlying Islands" : "미국령 군소 제도",
    "United States" : "미국",
    "Uruguay" : "우루과이",
    "Uzbekistan" : "우즈베키스탄",
    "Holy See" : "바티칸시국",
    "Saint Vincent and the Grenadines" : "세인트빈센트 그레나딘",
    "Venezuela" : "베네수엘라",
    "Virgin Islands (British)" : "영국령 버진 아일랜드",
    "Virgin Islands (U.S.)" : "미국령 버진 아일랜드",
    "Vietnam" : "베트남",
    "Vanuatu" : "바누아투",
    "Wallis and Futuna" : "왈리스에푸투나",
    "Samoa" : "사모아",
    "Yemen" : "예멘",
    "Mayotte" : "마요트섬",
    "South Africa" : "남아프리카공화국",
    "Zambia" : "잠비아",
    "Zimbabwe" : "짐바브웨",
    "The admin has not selected the location of the server yet." : "관리자가 서버 위치를 지정하지 않았습니다.",
    "You don't have any shares with individual users." : "개인 사용자와 공유한 항목이 없습니다.",
    "Your %s account" : "내 %s 계정",
    "Defining basic rights for people to control their own data in the internet age" : "인터넷에서 사람들의 데이터를 제어하는 기본 권리 선언",
    "People you shared with" : "공유한 다른 사람",
    "Read the privacy policy." : "개인 정보 취급 방침을 읽습니다."
},
"nplurals=1; plural=0;");
